@@ -55,7 +55,7 @@ s_char	*sys_siglist[] = {
 	"data pending",
 };
 #else
-#ifndef linux
+#if (!defined linux) && (!defined FBSD)
 /* linux declares sys_siglist in signal.h */
 extern	s_char *sys_siglist[];
 #endif /* linux */
@@ -64,13 +64,13 @@ extern	s_char *sys_siglist[];
 s_char * signame(sig)
 	int	sig;
 {
-#ifdef SVR4
+#ifdef POSIX_SIGNALS
 	if (sig <= 0 || sig > _sys_nsig)
 		return "bad signal";
 	return _sys_siglist[sig];
-#else /*SVR4 */
+#else /* POSIX_SIGNALS */
 	if (sig <= 0 || sig > NSIG)
 		return "bad signal";
 	return sys_siglist[sig];
-#endif /* SVR4 */
+#endif /* POSIX_SIGNALS */
 }
