@@ -47,6 +47,7 @@ int	buildem; /* Build = 1, maintain =0 */
 	int	lcm,hcm,lcm_needed,hcm_needed;
 	int	mil,mil_needed;
 	int	svec[I_MAX+1];
+	int     mvec[I_MAX+1];
 	int	n, k=0;
 	struct	shpstr *shp;
 	struct	plchrstr *desc;
@@ -170,117 +171,39 @@ int	buildem; /* Build = 1, maintain =0 */
 				left = delta;
 
         		leftp = ((float)left/100.0);
-        		mil_needed = ldround((double)(plp->pl_crew * leftp),1);
-        		lcm_needed = ldround((double)(plp->pl_lcm * leftp),1);
-        		hcm_needed = ldround((double)(plp->pl_hcm * leftp),1);
+			bzero(mvec, sizeof(mvec));
+        		mvec[I_MILIT] = mil_needed = 
+                                     ldround((double)(plp->pl_crew * leftp),1);
+        		mvec[I_LCM] = lcm_needed = 
+                                     ldround((double)(plp->pl_lcm * leftp),1);
+        		mvec[I_HCM] = hcm_needed = 
+                                     ldround((double)(plp->pl_hcm * leftp),1);
 
-			if (opt_GRAB_THINGS) {
-			/* try_supply_commod will get from this sect first,
-			 * then look elsewhere until it finds what it needs.
-			 * It'll return the number of mil/lcm/hcm/etc it
-			 * finds available without actually getting it.
-			 */
-
-				mil = try_supply_commod(sp->sct_own,
-							sp->sct_x,sp->sct_y,
-							I_MILIT,mil_needed);
-				lcm = try_supply_commod(sp->sct_own,
-							sp->sct_x,sp->sct_y,
-							I_LCM,lcm_needed);
-				hcm = try_supply_commod(sp->sct_own,
-							sp->sct_x,sp->sct_y,
-							I_HCM,hcm_needed);
-			}
-			else {	/* dont GRAB_THINGS */
-			        if (update_pending) {
-				  mil = svec[I_MILIT];
-				  lcm = svec[I_LCM];
-				  hcm = svec[I_HCM];
-				} else {
-				  mil = gt_bg_nmbr(bp, sp, I_MILIT);
-				  lcm = gt_bg_nmbr(bp, sp, I_LCM);
-				  hcm = gt_bg_nmbr(bp, sp, I_HCM);
-				}
-
-			} /* end not GRAB_THINGS */
-
-        		if (mil>=mil_needed)
+			get_materials(sp, bp, mvec, 0);
+ 
+        		if (mvec[I_MILIT]>=mil_needed)
                 		buildp=leftp;
         		else
-                		buildp=((float)mil/(float)plp->pl_crew);
+                		buildp=((float)mvec[I_MILIT]/(float)plp->pl_crew);
 	
-        		if (lcm < lcm_needed)
-                		buildp = MIN(buildp,((float)lcm/
+        		if (mvec[I_LCM] < lcm_needed)
+                		buildp = MIN(buildp,((float)mvec[I_LCM]/
 					(float)plp->pl_lcm));
 
-        		if (hcm < hcm_needed)
-                		buildp = MIN(buildp,((float)hcm/
+        		if (mvec[I_HCM] < hcm_needed)
+                		buildp = MIN(buildp,((float)mvec[I_HCM]/
 					(float)plp->pl_hcm));
 
 			build=ldround((double)(buildp*100.0),1);
+			bzero(mvec, sizeof(mvec));
+        		mvec[I_MILIT] = mil_needed = 
+                                     roundavg((double)(plp->pl_crew * buildp));
+        		mvec[I_LCM] = lcm_needed = 
+                                     roundavg((double)(plp->pl_lcm * buildp));
+        		mvec[I_HCM] = hcm_needed = 
+                                     roundavg((double)(plp->pl_hcm * buildp));
 
-        		mil_needed = roundavg((double)(plp->pl_crew * buildp));
-        		lcm_needed = roundavg((double)(plp->pl_lcm * buildp));
-        		hcm_needed = roundavg((double)(plp->pl_hcm * buildp));
-
-			if (opt_GRAB_THINGS) {
-				/*
-				 * Now that we know how much we can
-				 * actually use, go and get it.
-				 * supply_commod will actually subtract the commod
-				 * off the sector/ship/supply unit.
-				 */
-
-				mil = hcm = lcm = 0;
-				mil += supply_commod(sp->sct_own,
-						     sp->sct_x,sp->sct_y,
-						     I_MILIT,mil_needed);
-				lcm += supply_commod(sp->sct_own,sp->sct_x,sp->sct_y,
-						     I_LCM,lcm_needed);
-				hcm += supply_commod(sp->sct_own,
-						     sp->sct_x,sp->sct_y,
-						     I_HCM,hcm_needed);
-
-				/*
-				 * get the sect again, so we don't
-				 * overwrite it if supply_commod changed it
-				 */
-				sp = getsectp(pp->pln_x, pp->pln_y);
-			}
-			else /* dont GRAB_THINGS */
-			{
-			        if (update_pending) {
-				  if ((svec[I_MILIT] - mil_needed) < 0)
-				    svec[I_MILIT] = 0;
-				  else
-				    svec[I_MILIT] -= mil_needed;
-
-				  if ((svec[I_LCM] - lcm_needed) < 0)
-				    svec[I_LCM] = 0;
-				  else
-				    svec[I_LCM] -= lcm_needed;
-
-				  if ((svec[I_HCM] - hcm_needed) < 0)
-				    svec[I_HCM] = 0;
-				  else
-				    svec[I_HCM] -= hcm_needed;
-				} else {
-				  if ((gt_bg_nmbr(bp,sp,I_MILIT)-mil_needed)<0)
-				    pt_bg_nmbr(bp,sp,I_MILIT,0);
-				  else
-				    pt_bg_nmbr(bp,sp,I_MILIT,gt_bg_nmbr(bp,sp,I_MILIT)-mil_needed);
-				  if ((gt_bg_nmbr(bp,sp,I_LCM)-lcm_needed)<0)
-				    pt_bg_nmbr(bp,sp,I_LCM,0);
-				  else
-				    pt_bg_nmbr(bp,sp,I_LCM,gt_bg_nmbr(bp,sp,I_LCM)-lcm_needed);
-				  if((gt_bg_nmbr(bp,sp,I_HCM)-hcm_needed)<0)
-				    pt_bg_nmbr(bp,sp,I_HCM,0);
-				  else
-				    pt_bg_nmbr(bp,sp,I_HCM,gt_bg_nmbr(bp,sp,I_HCM)-hcm_needed);
-				}
-
-				putvec(VT_ITEM, svec, (s_char *)sp, EF_SECTOR);
-			} /* GRAB_THINGS */
+			get_materials(sp, bp, mvec, 1);
 
 			if (onship) build = delta;
 			used = build * w_p_eff;
